@@ -1,4 +1,5 @@
 import os
+import re
 import json
 import hashlib
 from datetime import datetime, timedelta
@@ -25,6 +26,7 @@ from sqlalchemy import (
     asc,
     desc,
     update,
+    or_,
 )
 from sqlalchemy.exc import IntegrityError
 from sqlalchemy.ext.hybrid import hybrid_property
@@ -39,6 +41,7 @@ from sqlalchemy.engine.interfaces import ExecutionContext
 
 from cidc_schemas import prism, unprism, json_validation
 
+from .facets import get_facets_for_paths
 from ..config.db import BaseModel
 from ..config.settings import (
     PAGINATION_PAGE_SIZE,
@@ -155,8 +158,10 @@ class CommonColumns(BaseModel):  # type: ignore
 
         # Handle sorting
         if sort_field:
+            # Get the attribute from the class, in case this is a hybrid attribute
+            sort_attribute = getattr(cls, sort_field)
             field_with_dir = (
-                asc(sort_field) if sort_direction == "asc" else desc(sort_field)
+                asc(sort_attribute) if sort_direction == "asc" else desc(sort_attribute)
             )
             query = query.order_by(field_with_dir)
 
@@ -348,7 +353,7 @@ class ValidationMultiError(Exception):
     pass
 
 
-trial_metadata_validator = json_validation.load_and_validate_schema(
+trial_metadata_validator: json_validation._Validator = json_validation.load_and_validate_schema(
     "clinical_trial.json", return_validator=True
 )
 
@@ -364,8 +369,8 @@ class TrialMetadata(CommonColumns):
 
     @validates("metadata_json")
     def validate_metadata_json(self, key, metadata_json):
-        errs = trial_metadata_validator.iter_errors(metadata_json)
-        messages = list(f"'metadata_json': {err.message}" for err in errs)
+        errs = trial_metadata_validator.iter_error_messages(metadata_json)
+        messages = list(f"'metadata_json': {err}" for err in errs)
         if messages:
             raise ValidationMultiError(messages)
         return metadata_json
@@ -755,12 +760,20 @@ class DownloadableFiles(CommonColumns):
     clustergrammer = Column(JSONB, nullable=True)
     ihc_combined_plot = Column(JSONB, nullable=True)
 
+    FILE_EXT_REGEX = r"\.([^./]*(\.gz)?)$"
+
+    @hybrid_property
+    def file_ext(self):
+        match = re.search(self.FILE_EXT_REGEX, self.object_url)
+        return match.group(1) if match else None
+
+    @file_ext.expression
+    def file_ext(cls):
+        return func.substring(cls.object_url, cls.FILE_EXT_REGEX)
+
     @staticmethod
     def build_file_filter(
-        trial_ids: List[str] = None,
-        upload_types: List[str] = None,
-        analysis_friendly: bool = False,
-        user: Users = None,
+        trial_ids: List[str] = [], facets: List[List[str]] = [], user: Users = None
     ) -> Callable[[Query], Query]:
         """
         Build a file filter function based on the provided parameters. The resultant
@@ -779,10 +792,11 @@ class DownloadableFiles(CommonColumns):
         file_filters = []
         if trial_ids:
             file_filters.append(DownloadableFiles.trial_id.in_(trial_ids))
-        if upload_types:
-            file_filters.append(DownloadableFiles.upload_type.in_(upload_types))
-        if analysis_friendly:
-            file_filters.append(DownloadableFiles.analysis_friendly == True)
+        if facets:
+            facet_filters = get_facets_for_paths(
+                DownloadableFiles.object_url.like, facets
+            )
+            file_filters.append(or_(*facet_filters))
         if user and not user.is_admin():
             permissions = Permissions.find_for_user(user.id)
             perm_set = [(p.trial_id, p.upload_type) for p in permissions]
